@@ -1,5 +1,7 @@
 import json
 import logging
+import os
+from contextlib import suppress
 from pathlib import Path
 
 import httpx
