@@ -8,6 +8,7 @@ import httpx
 
 from yappa.settings import DEFAULT_CONFIG_FILENAME
 from yappa.utils import load_yaml
+from .handle_utils import (set_access_token, update_django_pg_connection)
 
 logger = logging.getLogger(__name__)
 
@@ -34,17 +35,18 @@ def call_app(app, event):
     with httpx.Client(app=app,
                       base_url=host_url) as client:
         request = client.build_request(
-                method=event["httpMethod"],
-                url=event["url"],
-                headers=event["headers"],
-                params=event["queryStringParameters"],
-                content=json.dumps(event["body"]).encode(),
-                )
+            method=event["httpMethod"],
+            url=event["url"],
+            headers=event["headers"],
+            params=event["queryStringParameters"],
+            content=json.dumps(event["body"]).encode(),
+        )
         response = client.send(request)
         return response
 
 
 try:
+    set_access_token()
     config = load_yaml(Path(Path(__file__).resolve().parent.parent,
                             DEFAULT_CONFIG_FILENAME))
 
@@ -64,27 +66,20 @@ def patch_response(response):
     }
     """
     return {
-            'statusCode': response.status_code,
-            'headers': dict(response.headers),
-            'body': response.content.decode(),
-            'isBase64Encoded': False,
-            }
+        'statusCode': response.status_code,
+        'headers': dict(response.headers),
+        'body': response.content.decode(),
+        'isBase64Encoded': False,
+    }
 
 
 def handle(event, context):
+    set_access_token()
     if not event:
-        return {
-                'statusCode': 500,
-                'body': "got empty event",
-                }
+        raise ValueError("Got empty event")
 
+    if config["django_settings_module"]:
+        update_django_pg_connection(context.token["access_token"])
+        # TODO check if it's necessary to update db settings
     response = call_app(app, event)
-    if not config["debug"]:
-        return patch_response(response)
-    return {
-            'statusCode': 200,
-            'body': {
-                    "event": event,
-                    "response": response,
-                    },
-            }
+    return patch_response(response)
