@@ -1,10 +1,19 @@
+import yaml
+
+try:
+    from yaml import CLoader as Loader, CDumper as Dumper
+except ImportError:
+    from yaml import Loader, Dumper
+
+from yappa.settings import HANDLERS
+
 MIN_MEMORY, MAX_MEMORY = 134217728, 2147483648
 
 SIZE_SUFFIXES = {
-    'kb': 1024,
-    'mb': 1024 * 1024,
-    'gb': 1024 * 1024 * 1024,
-}
+        'kb': 1024,
+        'mb': 1024 * 1024,
+        'gb': 1024 * 1024 * 1024,
+        }
 
 
 def convert_size_to_bytes(size_str):
@@ -19,20 +28,31 @@ def convert_size_to_bytes(size_str):
                      "It should be in format 128MB, 2GB")
 
 
-HANDLERS = {
-    "wsgi": "handlers.wsgi.handle",
-    "django": "handlers.wsgi.handle",
-    "raw": None,
-}
-
-
 def get_yc_entrypoint(application_type, raw_entrypoint):
     entrypoint = HANDLERS.get(application_type)
     if application_type == "raw":
         entrypoint = raw_entrypoint
     if not entrypoint:
         raise ValueError(
-            f"Sorry, supported app types are: {','.join(HANDLERS.keys())}. "
-            f"Got {application_type}"
-        )
+                f"Sorry, supported app types are: "
+                f"{','.join(HANDLERS.keys())}. "
+                f"Got {application_type}"
+                )
     return entrypoint
+
+
+def load_yaml(file, safe=False):
+    try:
+        with open(file, "r") as f:
+            return yaml.load(f.read(), Loader)
+    except FileNotFoundError:
+        if safe:
+            return dict()
+        else:
+            raise
+
+
+def save_yaml(config, filename):
+    with open(filename, "w+") as f:
+        f.write(yaml.dump(config, sort_keys=False))
+    return filename
