@@ -16,8 +16,11 @@ class YC(YcAccessMixin, YcFunctionsMixin, YcGatewayMixin):
                  service_account_key=None):
         self.sdk = yandexcloud.SDK(token=token,
                                    service_account_key=service_account_key)
-        self.service_account_id = (service_account_key.get("service_account_id")
-                                   if service_account_key else None)
+        self.service_account_id = (
+            service_account_key.get("service_account_id")
+            if service_account_key else None)
+        self.token = token
+        self.service_account_key = service_account_key
         self.folder_id = folder_id
         self.function = None
         self.gateway = None
@@ -31,8 +34,8 @@ class YC(YcAccessMixin, YcFunctionsMixin, YcGatewayMixin):
           YC_FOLDER env variable
         """
         credentials = {
-            "token": token or os.environ.get("YC_OAUTH"),
-        }
+                "token": token or os.environ.get("YC_OAUTH"),
+                }
         if not credentials["token"]:
             del credentials["token"]
             with suppress(FileNotFoundError):
